@@ -154,12 +154,17 @@ Module documentation
 """
 
 import datetime
+import logging
 import os
 
 import aspecd.exceptions
 import aspecd.utils
 
 
+logger = logging.getLogger(__name__)
+logger.addHandler(logging.NullHandler())
+
+
 class PhysicalQuantity(aspecd.utils.ToDictMixin):
     """
     Class for storing all relevant informations about a physical quantity.
@@ -811,6 +816,27 @@ class MetadataMapper:
         Needs to be specified when you use :meth:`create_mappings` to
         create the mappings from mapping recipes stored in a YAML file.
 
+    Examples
+    --------
+    To actually use the mapper, you will usually create a file (in YAML
+    format) containing the mappings. For details how this file may look
+    like, see the :meth:`create_mappings` method. Suppose you have saved
+    your mappings to the file ``mappings.yaml``, with different mappings for
+    the different versions of your formats. In this case, using the mapper
+    may look similar to the following:
+
+    .. code-block::
+
+        mapper = aspecd.metadata.MetadataMapper()
+        mapper.version = version_string
+        mapper.metadata = dict_to_be_mapped
+        mapper.recipe_filename = 'mappings.yaml'
+        mapper.map()
+        modified_dict = mapper.metadata
+
+    As you can see, the ``modified_dict`` contains the dictionary where the
+    mappings from ``mappings.yaml`` have been applied to.
+
     """
 
     def __init__(self):
@@ -840,7 +866,10 @@ class MetadataMapper:
 
     @staticmethod
     def _rename_key_in_dict(old_key='', new_key='', dict_=None):
-        dict_[new_key] = dict_.pop(old_key)
+        if old_key in dict_:
+            dict_[new_key] = dict_.pop(old_key)
+        else:
+            logger.debug('Key "%s" not found', old_key)
         return dict_
 
     def combine_items(self, old_keys=None, new_key='', pattern=''):
@@ -950,7 +979,14 @@ class MetadataMapper:
                            create_target_dict=False, dict_=None):
         if create_target_dict and target_dict_name not in dict_:
             dict_[target_dict_name] = {}
-        dict_[target_dict_name][key] = dict_[source_dict_name].pop(key)
+        if source_dict_name:
+            source_dict = dict_[source_dict_name]
+        else:
+            source_dict = dict_
+        if key in source_dict:
+            dict_[target_dict_name][key] = source_dict.pop(key)
+        else:
+            logger.debug('Key "%s" not found in "%s"', key, source_dict_name)
 
     def map(self):
         """
@@ -1021,7 +1057,10 @@ class MetadataMapper:
         for mapping in self.mappings:
             if mapping[0]:
                 method = getattr(self, ''.join(['_', mapping[1], '_in_dict']))
-                method(*mapping[2], dict_=self.metadata[mapping[0]])
+                if mapping[0] in self.metadata:
+                    method(*mapping[2], dict_=self.metadata[mapping[0]])
+                else:
+                    logger.debug('Key "%s" not found', mapping[0])
             else:
                 method = getattr(self, mapping[1])
                 method(*mapping[2])
@@ -1048,7 +1087,7 @@ class MetadataMapper:
 
             format:
               type: metadata mapper
-              version: 0.0.1
+              version: '0.1'
 
             map 1:
               metadata file versions:
@@ -1086,6 +1125,13 @@ class MetadataMapper:
         introduced in your mapping recipe will lead to hard-to-debug
         behaviour of your application. See :meth:`move_item` for details.
 
+        .. important::
+
+            If you have version numbers with only one dot, you need to
+            explicitly mark this as string in YAML, as otherwise, it will
+            automatically be converted into a float and hence your version
+            lookup will fail.
+
         Generally, the YAML file should be pretty self-explanatory. For
         details of the different mappings, see the documentation of the
         respective methods of the class, namely :meth:`combine_items`,
