@@ -92,7 +92,8 @@ class ToDictMixin:
 
         Usually, the reason to exclude public attributes from being added to
         the dictionary is to avoid infinite loops, as sometimes an object
-        may contain a reference to another object that in turn references back.
+        may contain a reference to another object that in turn references
+        back.
 
     _include_in_to_dict : :class:`list`
         Names of (public) attributes to include into dictionary
@@ -301,11 +302,20 @@ class Yaml:
 
         Default: 100 -- *i.e.*, arrays with >100 elements are stored in files.
 
+    numpy_array_to_list : class:`bool`
+        Whether to convert (small) NumPy arrays to a list or to a dict
+
+        Default: False
+
     Raises
     ------
     aspecd.utils.MissingFilenameError
         Raised if no filename is given to read from/write to
 
+
+    .. versionchanged:: 0.4
+        Added :attr:`numpy_array_to_list`
+
     """
 
     def __init__(self):
@@ -313,6 +323,7 @@ class Yaml:
         self.binary_directory = ''
         self.dict = collections.OrderedDict()
         self.numpy_array_size_threshold = 100
+        self.numpy_array_to_list = False
         self.loader = yaml.SafeLoader
         self.loader.add_implicit_resolver(
             u'tag:yaml.org,2002:float',
@@ -395,10 +406,10 @@ class Yaml:
 
         Background: The PyYAML package cannot easily handle NumPy arrays out
         of the box. However, datasets and alike should sometimes be
-        serialised in form of YAML files. Hence the need for a simple method of
-        serialising NumPy arrays. Furthermore, larger NumPy arrays should
-        not be serialised in text form in YAML directly, but rather be
-        stored in binary form, probably in a separate file.
+        serialised in form of YAML files. Hence the need for a simple
+        method of serialising NumPy arrays. Furthermore, larger NumPy
+        arrays should not be serialised in text form in YAML directly,
+        but rather be stored in binary form, probably in a separate file.
 
         The reason for saving (larger) NumPy arrays in binary rather than
         text form is twofold: The size of a binary file is much smaller,
@@ -423,7 +434,7 @@ class Yaml:
         """
         self._traverse_serialise_numpy_arrays(dict_=self.dict)
 
-    def _traverse_serialise_numpy_arrays(self, dict_=None):
+    def _traverse_serialise_numpy_arrays(self, dict_=None):  # noqa: MC0001
         for key in dict_.keys():
             if isinstance(dict_[key], list):
                 for element in dict_[key]:
@@ -444,6 +455,8 @@ class Yaml:
                                   'dtype': str(dict_[key].dtype),
                                   'file': filename}
                     self.binary_files.append(filename)
+                elif self.numpy_array_to_list:
+                    dict_[key] = dict_[key].tolist()
                 else:
                     dict_[key] = {'type': 'numpy.ndarray',
                                   'dtype': str(dict_[key].dtype),
@@ -501,7 +514,8 @@ class Yaml:
         self.deserialise_numpy_arrays()
 
     def _create_binary_directory(self):
-        if self.binary_directory and not os.path.exists(self.binary_directory):
+        if self.binary_directory and not os.path.exists(
+                self.binary_directory):
             os.mkdir(self.binary_directory)
 
 
@@ -540,7 +554,8 @@ def replace_value_in_dict(replacement=None, target=None):  # noqa: MC0001
                     if isinstance(list_element, dict):
                         target[key][list_index] = \
                             replace_value_in_dict(replacement, list_element)
-                    elif list_element.__hash__ and list_element in replacement:
+                    elif list_element.__hash__ and list_element in \
+                            replacement:
                         target[key][list_index] = replacement[list_element]
                     else:
                         target[key][list_index] = list_element
@@ -755,8 +770,8 @@ def basename(filename):
     Parameters
     ----------
     filename : :class:`str`
-        Name of the file (may contain absolute path and extension) the basename
-        should be returned for.
+        Name of the file (may contain absolute path and extension) the
+        basename should be returned for.
 
     Returns
     -------
@@ -817,10 +832,11 @@ def not_zero(value):
     .. versionadded:: 0.3
 
     """
-    return np.copysign(max(abs(value), np.finfo(np.float64).resolution), value)
+    return np.copysign(max(abs(value), np.finfo(np.float64).resolution),
+                       value)
 
 
-def iterable(variable):
+def isiterable(variable):
     """
     Check whether the given variable is iterable.
 
